# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: commands/v1/oracles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='commands/v1/oracles.proto',
  package='vega.commands.v1',
  syntax='proto3',
  serialized_options=b'\n io.vegaprotocol.vega.commands.v1Z+code.vegaprotocol.io/vega/proto/commands/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x63ommands/v1/oracles.proto\x12\x10vega.commands.v1\"\xcb\x01\n\x14OracleDataSubmission\x12K\n\x06source\x18\x01 \x01(\x0e\x32\x33.vega.commands.v1.OracleDataSubmission.OracleSourceR\x06source\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload\"L\n\x0cOracleSource\x12\x1d\n\x19ORACLE_SOURCE_UNSPECIFIED\x10\x00\x12\x1d\n\x19ORACLE_SOURCE_OPEN_ORACLE\x10\x01\x42O\n io.vegaprotocol.vega.commands.v1Z+code.vegaprotocol.io/vega/proto/commands/v1b\x06proto3'
)



_ORACLEDATASUBMISSION_ORACLESOURCE = _descriptor.EnumDescriptor(
  name='OracleSource',
  full_name='vega.commands.v1.OracleDataSubmission.OracleSource',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORACLE_SOURCE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORACLE_SOURCE_OPEN_ORACLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=175,
  serialized_end=251,
)
_sym_db.RegisterEnumDescriptor(_ORACLEDATASUBMISSION_ORACLESOURCE)


_ORACLEDATASUBMISSION = _descriptor.Descriptor(
  name='OracleDataSubmission',
  full_name='vega.commands.v1.OracleDataSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='vega.commands.v1.OracleDataSubmission.source', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='source', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='vega.commands.v1.OracleDataSubmission.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='payload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ORACLEDATASUBMISSION_ORACLESOURCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=251,
)

_ORACLEDATASUBMISSION.fields_by_name['source'].enum_type = _ORACLEDATASUBMISSION_ORACLESOURCE
_ORACLEDATASUBMISSION_ORACLESOURCE.containing_type = _ORACLEDATASUBMISSION
DESCRIPTOR.message_types_by_name['OracleDataSubmission'] = _ORACLEDATASUBMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OracleDataSubmission = _reflection.GeneratedProtocolMessageType('OracleDataSubmission', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEDATASUBMISSION,
  '__module__' : 'commands.v1.oracles_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.OracleDataSubmission)
  })
_sym_db.RegisterMessage(OracleDataSubmission)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: commands/v1/commands.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ... import governance_pb2 as governance__pb2
from ... import vega_pb2 as vega__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ...github.com.mwitkow.go_proto_validators import validator_pb2 as github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='commands/v1/commands.proto',
  package='vega.commands.v1',
  syntax='proto3',
  serialized_options=b'\n io.vegaprotocol.vega.commands.v1Z+code.vegaprotocol.io/vega/proto/commands/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x63ommands/v1/commands.proto\x12\x10vega.commands.v1\x1a\x10governance.proto\x1a\nvega.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x36github.com/mwitkow/go-proto-validators/validator.proto\"\xde\x02\n\x0fOrderSubmission\x12#\n\tmarket_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x08marketId\x12\x14\n\x05price\x18\x02 \x01(\x04R\x05price\x12\x1a\n\x04size\x18\x03 \x01(\x04\x42\x06\xe2\xdf\x1f\x02\x10\x00R\x04size\x12\x1e\n\x04side\x18\x04 \x01(\x0e\x32\n.vega.SideR\x04side\x12;\n\rtime_in_force\x18\x05 \x01(\x0e\x32\x17.vega.Order.TimeInForceR\x0btimeInForce\x12\x1d\n\nexpires_at\x18\x06 \x01(\x03R\texpiresAt\x12$\n\x04type\x18\x07 \x01(\x0e\x32\x10.vega.Order.TypeR\x04type\x12\x1c\n\treference\x18\x08 \x01(\tR\treference\x12\x34\n\x0cpegged_order\x18\t \x01(\x0b\x32\x11.vega.PeggedOrderR\x0bpeggedOrder\"K\n\x11OrderCancellation\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"\x83\x03\n\x0eOrderAmendment\x12!\n\x08order_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x07orderId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12!\n\x05price\x18\x03 \x01(\x0b\x32\x0b.vega.PriceR\x05price\x12\x1d\n\nsize_delta\x18\x04 \x01(\x03R\tsizeDelta\x12.\n\nexpires_at\x18\x05 \x01(\x0b\x32\x0f.vega.TimestampR\texpiresAt\x12;\n\rtime_in_force\x18\x06 \x01(\x0e\x32\x17.vega.Order.TimeInForceR\x0btimeInForce\x12@\n\rpegged_offset\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0cpeggedOffset\x12@\n\x10pegged_reference\x18\x08 \x01(\x0e\x32\x15.vega.PeggedReferenceR\x0fpeggedReference\"\xf6\x01\n\x1cLiquidityProvisionSubmission\x12#\n\tmarket_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x08marketId\x12+\n\x11\x63ommitment_amount\x18\x02 \x01(\x04R\x10\x63ommitmentAmount\x12\x10\n\x03\x66\x65\x65\x18\x03 \x01(\tR\x03\x66\x65\x65\x12*\n\x05sells\x18\x04 \x03(\x0b\x32\x14.vega.LiquidityOrderR\x05sells\x12(\n\x04\x62uys\x18\x05 \x03(\x0b\x32\x14.vega.LiquidityOrderR\x04\x62uys\x12\x1c\n\treference\x18\x06 \x01(\tR\treference\"g\n\x12WithdrawSubmission\x12\x16\n\x06\x61mount\x18\x01 \x01(\x04R\x06\x61mount\x12\x14\n\x05\x61sset\x18\x02 \x01(\tR\x05\x61sset\x12#\n\x03\x65xt\x18\x03 \x01(\x0b\x32\x11.vega.WithdrawExtR\x03\x65xt\"e\n\x12ProposalSubmission\x12\x1c\n\treference\x18\x01 \x01(\tR\treference\x12\x31\n\x05terms\x18\x02 \x01(\x0b\x32\x13.vega.ProposalTermsB\x06\xe2\xdf\x1f\x02 \x01R\x05terms\"a\n\x0eVoteSubmission\x12\'\n\x0bproposal_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\nproposalId\x12&\n\x05value\x18\x02 \x01(\x0e\x32\x10.vega.Vote.ValueR\x05valueBO\n io.vegaprotocol.vega.commands.v1Z+code.vegaprotocol.io/vega/proto/commands/v1b\x06proto3'
  ,
  dependencies=[governance__pb2.DESCRIPTOR,vega__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2.DESCRIPTOR,])




_ORDERSUBMISSION = _descriptor.Descriptor(
  name='OrderSubmission',
  full_name='vega.commands.v1.OrderSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.commands.v1.OrderSubmission.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.commands.v1.OrderSubmission.price', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='vega.commands.v1.OrderSubmission.size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', json_name='size', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='vega.commands.v1.OrderSubmission.side', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='side', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_in_force', full_name='vega.commands.v1.OrderSubmission.time_in_force', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeInForce', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='vega.commands.v1.OrderSubmission.expires_at', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expiresAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='vega.commands.v1.OrderSubmission.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.commands.v1.OrderSubmission.reference', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pegged_order', full_name='vega.commands.v1.OrderSubmission.pegged_order', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peggedOrder', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=517,
)


_ORDERCANCELLATION = _descriptor.Descriptor(
  name='OrderCancellation',
  full_name='vega.commands.v1.OrderCancellation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='vega.commands.v1.OrderCancellation.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.commands.v1.OrderCancellation.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=594,
)


_ORDERAMENDMENT = _descriptor.Descriptor(
  name='OrderAmendment',
  full_name='vega.commands.v1.OrderAmendment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='vega.commands.v1.OrderAmendment.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='orderId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.commands.v1.OrderAmendment.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.commands.v1.OrderAmendment.price', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_delta', full_name='vega.commands.v1.OrderAmendment.size_delta', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sizeDelta', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='vega.commands.v1.OrderAmendment.expires_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expiresAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_in_force', full_name='vega.commands.v1.OrderAmendment.time_in_force', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeInForce', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pegged_offset', full_name='vega.commands.v1.OrderAmendment.pegged_offset', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peggedOffset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pegged_reference', full_name='vega.commands.v1.OrderAmendment.pegged_reference', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peggedReference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=984,
)


_LIQUIDITYPROVISIONSUBMISSION = _descriptor.Descriptor(
  name='LiquidityProvisionSubmission',
  full_name='vega.commands.v1.LiquidityProvisionSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.commands.v1.LiquidityProvisionSubmission.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment_amount', full_name='vega.commands.v1.LiquidityProvisionSubmission.commitment_amount', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitmentAmount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='vega.commands.v1.LiquidityProvisionSubmission.fee', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fee', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sells', full_name='vega.commands.v1.LiquidityProvisionSubmission.sells', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sells', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buys', full_name='vega.commands.v1.LiquidityProvisionSubmission.buys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='buys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.commands.v1.LiquidityProvisionSubmission.reference', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1233,
)


_WITHDRAWSUBMISSION = _descriptor.Descriptor(
  name='WithdrawSubmission',
  full_name='vega.commands.v1.WithdrawSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.commands.v1.WithdrawSubmission.amount', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset', full_name='vega.commands.v1.WithdrawSubmission.asset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='asset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ext', full_name='vega.commands.v1.WithdrawSubmission.ext', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ext', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1235,
  serialized_end=1338,
)


_PROPOSALSUBMISSION = _descriptor.Descriptor(
  name='ProposalSubmission',
  full_name='vega.commands.v1.ProposalSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.commands.v1.ProposalSubmission.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terms', full_name='vega.commands.v1.ProposalSubmission.terms', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', json_name='terms', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1340,
  serialized_end=1441,
)


_VOTESUBMISSION = _descriptor.Descriptor(
  name='VoteSubmission',
  full_name='vega.commands.v1.VoteSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal_id', full_name='vega.commands.v1.VoteSubmission.proposal_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='proposalId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.commands.v1.VoteSubmission.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1540,
)

_ORDERSUBMISSION.fields_by_name['side'].enum_type = vega__pb2._SIDE
_ORDERSUBMISSION.fields_by_name['time_in_force'].enum_type = vega__pb2._ORDER_TIMEINFORCE
_ORDERSUBMISSION.fields_by_name['type'].enum_type = vega__pb2._ORDER_TYPE
_ORDERSUBMISSION.fields_by_name['pegged_order'].message_type = vega__pb2._PEGGEDORDER
_ORDERAMENDMENT.fields_by_name['price'].message_type = vega__pb2._PRICE
_ORDERAMENDMENT.fields_by_name['expires_at'].message_type = vega__pb2._TIMESTAMP
_ORDERAMENDMENT.fields_by_name['time_in_force'].enum_type = vega__pb2._ORDER_TIMEINFORCE
_ORDERAMENDMENT.fields_by_name['pegged_offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ORDERAMENDMENT.fields_by_name['pegged_reference'].enum_type = vega__pb2._PEGGEDREFERENCE
_LIQUIDITYPROVISIONSUBMISSION.fields_by_name['sells'].message_type = vega__pb2._LIQUIDITYORDER
_LIQUIDITYPROVISIONSUBMISSION.fields_by_name['buys'].message_type = vega__pb2._LIQUIDITYORDER
_WITHDRAWSUBMISSION.fields_by_name['ext'].message_type = vega__pb2._WITHDRAWEXT
_PROPOSALSUBMISSION.fields_by_name['terms'].message_type = governance__pb2._PROPOSALTERMS
_VOTESUBMISSION.fields_by_name['value'].enum_type = governance__pb2._VOTE_VALUE
DESCRIPTOR.message_types_by_name['OrderSubmission'] = _ORDERSUBMISSION
DESCRIPTOR.message_types_by_name['OrderCancellation'] = _ORDERCANCELLATION
DESCRIPTOR.message_types_by_name['OrderAmendment'] = _ORDERAMENDMENT
DESCRIPTOR.message_types_by_name['LiquidityProvisionSubmission'] = _LIQUIDITYPROVISIONSUBMISSION
DESCRIPTOR.message_types_by_name['WithdrawSubmission'] = _WITHDRAWSUBMISSION
DESCRIPTOR.message_types_by_name['ProposalSubmission'] = _PROPOSALSUBMISSION
DESCRIPTOR.message_types_by_name['VoteSubmission'] = _VOTESUBMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OrderSubmission = _reflection.GeneratedProtocolMessageType('OrderSubmission', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.OrderSubmission)
  })
_sym_db.RegisterMessage(OrderSubmission)

OrderCancellation = _reflection.GeneratedProtocolMessageType('OrderCancellation', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELLATION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.OrderCancellation)
  })
_sym_db.RegisterMessage(OrderCancellation)

OrderAmendment = _reflection.GeneratedProtocolMessageType('OrderAmendment', (_message.Message,), {
  'DESCRIPTOR' : _ORDERAMENDMENT,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.OrderAmendment)
  })
_sym_db.RegisterMessage(OrderAmendment)

LiquidityProvisionSubmission = _reflection.GeneratedProtocolMessageType('LiquidityProvisionSubmission', (_message.Message,), {
  'DESCRIPTOR' : _LIQUIDITYPROVISIONSUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.LiquidityProvisionSubmission)
  })
_sym_db.RegisterMessage(LiquidityProvisionSubmission)

WithdrawSubmission = _reflection.GeneratedProtocolMessageType('WithdrawSubmission', (_message.Message,), {
  'DESCRIPTOR' : _WITHDRAWSUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.WithdrawSubmission)
  })
_sym_db.RegisterMessage(WithdrawSubmission)

ProposalSubmission = _reflection.GeneratedProtocolMessageType('ProposalSubmission', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSALSUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.ProposalSubmission)
  })
_sym_db.RegisterMessage(ProposalSubmission)

VoteSubmission = _reflection.GeneratedProtocolMessageType('VoteSubmission', (_message.Message,), {
  'DESCRIPTOR' : _VOTESUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.VoteSubmission)
  })
_sym_db.RegisterMessage(VoteSubmission)


DESCRIPTOR._options = None
_ORDERSUBMISSION.fields_by_name['market_id']._options = None
_ORDERSUBMISSION.fields_by_name['size']._options = None
_ORDERAMENDMENT.fields_by_name['order_id']._options = None
_LIQUIDITYPROVISIONSUBMISSION.fields_by_name['market_id']._options = None
_PROPOSALSUBMISSION.fields_by_name['terms']._options = None
_VOTESUBMISSION.fields_by_name['proposal_id']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wallet/v1/wallet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...commands.v1 import commands_pb2 as commands_dot_v1_dot_commands__pb2
from ...commands.v1 import validator_commands_pb2 as commands_dot_v1_dot_validator__commands__pb2
from ...commands.v1 import oracles_pb2 as commands_dot_v1_dot_oracles__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='wallet/v1/wallet.proto',
  package='vega.wallet.v1',
  syntax='proto3',
  serialized_options=b'\n\036io.vegaprotocol.vega.wallet.v1Z)code.vegaprotocol.io/vega/proto/wallet/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16wallet/v1/wallet.proto\x12\x0evega.wallet.v1\x1a\x1a\x63ommands/v1/commands.proto\x1a$commands/v1/validator_commands.proto\x1a\x19\x63ommands/v1/oracles.proto\"\xcb\x08\n\x18SubmitTransactionRequest\x12\x17\n\x07pub_key\x18\x01 \x01(\tR\x06pubKey\x12\x1c\n\tpropagate\x18\x02 \x01(\x08R\tpropagate\x12O\n\x10order_submission\x18\xe9\x07 \x01(\x0b\x32!.vega.commands.v1.OrderSubmissionH\x00R\x0forderSubmission\x12U\n\x12order_cancellation\x18\xea\x07 \x01(\x0b\x32#.vega.commands.v1.OrderCancellationH\x00R\x11orderCancellation\x12L\n\x0forder_amendment\x18\xeb\x07 \x01(\x0b\x32 .vega.commands.v1.OrderAmendmentH\x00R\x0eorderAmendment\x12X\n\x13withdraw_submission\x18\xec\x07 \x01(\x0b\x32$.vega.commands.v1.WithdrawSubmissionH\x00R\x12withdrawSubmission\x12X\n\x13proposal_submission\x18\xed\x07 \x01(\x0b\x32$.vega.commands.v1.ProposalSubmissionH\x00R\x12proposalSubmission\x12L\n\x0fvote_submission\x18\xee\x07 \x01(\x0b\x32 .vega.commands.v1.VoteSubmissionH\x00R\x0evoteSubmission\x12w\n\x1eliquidity_provision_submission\x18\xef\x07 \x01(\x0b\x32..vega.commands.v1.LiquidityProvisionSubmissionH\x00R\x1cliquidityProvisionSubmission\x12R\n\x11node_registration\x18\xd1\x0f \x01(\x0b\x32\".vega.commands.v1.NodeRegistrationH\x00R\x10nodeRegistration\x12:\n\tnode_vote\x18\xd2\x0f \x01(\x0b\x32\x1a.vega.commands.v1.NodeVoteH\x00R\x08nodeVote\x12I\n\x0enode_signature\x18\xd3\x0f \x01(\x0b\x32\x1f.vega.commands.v1.NodeSignatureH\x00R\rnodeSignature\x12@\n\x0b\x63hain_event\x18\xd4\x0f \x01(\x0b\x32\x1c.vega.commands.v1.ChainEventH\x00R\nchainEvent\x12_\n\x16oracle_data_submission\x18\xb9\x17 \x01(\x0b\x32&.vega.commands.v1.OracleDataSubmissionH\x00R\x14oracleDataSubmissionB\t\n\x07\x63ommandBK\n\x1eio.vegaprotocol.vega.wallet.v1Z)code.vegaprotocol.io/vega/proto/wallet/v1b\x06proto3'
  ,
  dependencies=[commands_dot_v1_dot_commands__pb2.DESCRIPTOR,commands_dot_v1_dot_validator__commands__pb2.DESCRIPTOR,commands_dot_v1_dot_oracles__pb2.DESCRIPTOR,])




_SUBMITTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='SubmitTransactionRequest',
  full_name='vega.wallet.v1.SubmitTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='vega.wallet.v1.SubmitTransactionRequest.pub_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='propagate', full_name='vega.wallet.v1.SubmitTransactionRequest.propagate', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='propagate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.order_submission', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_cancellation', full_name='vega.wallet.v1.SubmitTransactionRequest.order_cancellation', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderCancellation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_amendment', full_name='vega.wallet.v1.SubmitTransactionRequest.order_amendment', index=4,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderAmendment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdraw_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.withdraw_submission', index=5,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withdrawSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.proposal_submission', index=6,
      number=1005, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='proposalSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.vote_submission', index=7,
      number=1006, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='voteSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liquidity_provision_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.liquidity_provision_submission', index=8,
      number=1007, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='liquidityProvisionSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_registration', full_name='vega.wallet.v1.SubmitTransactionRequest.node_registration', index=9,
      number=2001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeRegistration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_vote', full_name='vega.wallet.v1.SubmitTransactionRequest.node_vote', index=10,
      number=2002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeVote', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_signature', full_name='vega.wallet.v1.SubmitTransactionRequest.node_signature', index=11,
      number=2003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeSignature', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_event', full_name='vega.wallet.v1.SubmitTransactionRequest.chain_event', index=12,
      number=2004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='chainEvent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_data_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.oracle_data_submission', index=13,
      number=3001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oracleDataSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='vega.wallet.v1.SubmitTransactionRequest.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=136,
  serialized_end=1235,
)

_SUBMITTRANSACTIONREQUEST.fields_by_name['order_submission'].message_type = commands_dot_v1_dot_commands__pb2._ORDERSUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_cancellation'].message_type = commands_dot_v1_dot_commands__pb2._ORDERCANCELLATION
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_amendment'].message_type = commands_dot_v1_dot_commands__pb2._ORDERAMENDMENT
_SUBMITTRANSACTIONREQUEST.fields_by_name['withdraw_submission'].message_type = commands_dot_v1_dot_commands__pb2._WITHDRAWSUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['proposal_submission'].message_type = commands_dot_v1_dot_commands__pb2._PROPOSALSUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['vote_submission'].message_type = commands_dot_v1_dot_commands__pb2._VOTESUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['liquidity_provision_submission'].message_type = commands_dot_v1_dot_commands__pb2._LIQUIDITYPROVISIONSUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_registration'].message_type = commands_dot_v1_dot_validator__commands__pb2._NODEREGISTRATION
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_vote'].message_type = commands_dot_v1_dot_validator__commands__pb2._NODEVOTE
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_signature'].message_type = commands_dot_v1_dot_validator__commands__pb2._NODESIGNATURE
_SUBMITTRANSACTIONREQUEST.fields_by_name['chain_event'].message_type = commands_dot_v1_dot_validator__commands__pb2._CHAINEVENT
_SUBMITTRANSACTIONREQUEST.fields_by_name['oracle_data_submission'].message_type = commands_dot_v1_dot_oracles__pb2._ORACLEDATASUBMISSION
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['order_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['order_cancellation'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_cancellation'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['order_amendment'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_amendment'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['withdraw_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['withdraw_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['proposal_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['proposal_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['vote_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['vote_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['liquidity_provision_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['liquidity_provision_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['node_registration'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_registration'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['node_vote'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_vote'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['node_signature'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_signature'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['chain_event'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['chain_event'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['oracle_data_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['oracle_data_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
DESCRIPTOR.message_types_by_name['SubmitTransactionRequest'] = _SUBMITTRANSACTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmitTransactionRequest = _reflection.GeneratedProtocolMessageType('SubmitTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONREQUEST,
  '__module__' : 'wallet.v1.wallet_pb2'
  # @@protoc_insertion_point(class_scope:vega.wallet.v1.SubmitTransactionRequest)
  })
_sym_db.RegisterMessage(SubmitTransactionRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: commands/v1/validator_commands.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ... import chain_events_pb2 as chain__events__pb2
from ...github.com.mwitkow.go_proto_validators import validator_pb2 as github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='commands/v1/validator_commands.proto',
  package='vega.commands.v1',
  syntax='proto3',
  serialized_options=b'\n io.vegaprotocol.vega.commands.v1Z+code.vegaprotocol.io/vega/proto/commands/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$commands/v1/validator_commands.proto\x12\x10vega.commands.v1\x1a\x12\x63hain_events.proto\x1a\x36github.com/mwitkow/go-proto-validators/validator.proto\"_\n\x10NodeRegistration\x12\x1f\n\x07pub_key\x18\x01 \x01(\x0c\x42\x06\xe2\xdf\x1f\x02X\x01R\x06pubKey\x12*\n\rchain_pub_key\x18\x02 \x01(\x0c\x42\x06\xe2\xdf\x1f\x02X\x01R\x0b\x63hainPubKey\"Q\n\x08NodeVote\x12\x1f\n\x07pub_key\x18\x01 \x01(\x0c\x42\x06\xe2\xdf\x1f\x02X\x01R\x06pubKey\x12$\n\treference\x18\x02 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\treference\"j\n\rNodeSignature\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x10\n\x03sig\x18\x02 \x01(\x0cR\x03sig\x12\x37\n\x04kind\x18\x03 \x01(\x0e\x32#.vega.commands.v1.NodeSignatureKindR\x04kind\"\xfd\x01\n\nChainEvent\x12\x13\n\x05tx_id\x18\x01 \x01(\tR\x04txId\x12\x14\n\x05nonce\x18\x02 \x01(\x04R\x05nonce\x12\x34\n\x07\x62uiltin\x18\xe9\x07 \x01(\x0b\x32\x17.vega.BuiltinAssetEventH\x00R\x07\x62uiltin\x12)\n\x05\x65rc20\x18\xea\x07 \x01(\x0b\x32\x10.vega.ERC20EventH\x00R\x05\x65rc20\x12#\n\x03\x62tc\x18\xeb\x07 \x01(\x0b\x32\x0e.vega.BTCEventH\x00R\x03\x62tc\x12\x35\n\tvalidator\x18\xec\x07 \x01(\x0b\x32\x14.vega.ValidatorEventH\x00R\tvalidatorB\x07\n\x05\x65vent*\x85\x01\n\x11NodeSignatureKind\x12#\n\x1fNODE_SIGNATURE_KIND_UNSPECIFIED\x10\x00\x12!\n\x1dNODE_SIGNATURE_KIND_ASSET_NEW\x10\x01\x12(\n$NODE_SIGNATURE_KIND_ASSET_WITHDRAWAL\x10\x02\x42O\n io.vegaprotocol.vega.commands.v1Z+code.vegaprotocol.io/vega/proto/commands/v1b\x06proto3'
  ,
  dependencies=[chain__events__pb2.DESCRIPTOR,github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2.DESCRIPTOR,])

_NODESIGNATUREKIND = _descriptor.EnumDescriptor(
  name='NodeSignatureKind',
  full_name='vega.commands.v1.NodeSignatureKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NODE_SIGNATURE_KIND_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODE_SIGNATURE_KIND_ASSET_NEW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODE_SIGNATURE_KIND_ASSET_WITHDRAWAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=679,
  serialized_end=812,
)
_sym_db.RegisterEnumDescriptor(_NODESIGNATUREKIND)

NodeSignatureKind = enum_type_wrapper.EnumTypeWrapper(_NODESIGNATUREKIND)
NODE_SIGNATURE_KIND_UNSPECIFIED = 0
NODE_SIGNATURE_KIND_ASSET_NEW = 1
NODE_SIGNATURE_KIND_ASSET_WITHDRAWAL = 2



_NODEREGISTRATION = _descriptor.Descriptor(
  name='NodeRegistration',
  full_name='vega.commands.v1.NodeRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='vega.commands.v1.NodeRegistration.pub_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='pubKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_pub_key', full_name='vega.commands.v1.NodeRegistration.chain_pub_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='chainPubKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=229,
)


_NODEVOTE = _descriptor.Descriptor(
  name='NodeVote',
  full_name='vega.commands.v1.NodeVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='vega.commands.v1.NodeVote.pub_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='pubKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.commands.v1.NodeVote.reference', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=312,
)


_NODESIGNATURE = _descriptor.Descriptor(
  name='NodeSignature',
  full_name='vega.commands.v1.NodeSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.commands.v1.NodeSignature.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sig', full_name='vega.commands.v1.NodeSignature.sig', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='vega.commands.v1.NodeSignature.kind', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kind', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=420,
)


_CHAINEVENT = _descriptor.Descriptor(
  name='ChainEvent',
  full_name='vega.commands.v1.ChainEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='vega.commands.v1.ChainEvent.tx_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='txId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='vega.commands.v1.ChainEvent.nonce', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nonce', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='builtin', full_name='vega.commands.v1.ChainEvent.builtin', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='builtin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='erc20', full_name='vega.commands.v1.ChainEvent.erc20', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='erc20', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='btc', full_name='vega.commands.v1.ChainEvent.btc', index=4,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='btc', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='vega.commands.v1.ChainEvent.validator', index=5,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='vega.commands.v1.ChainEvent.event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=423,
  serialized_end=676,
)

_NODESIGNATURE.fields_by_name['kind'].enum_type = _NODESIGNATUREKIND
_CHAINEVENT.fields_by_name['builtin'].message_type = chain__events__pb2._BUILTINASSETEVENT
_CHAINEVENT.fields_by_name['erc20'].message_type = chain__events__pb2._ERC20EVENT
_CHAINEVENT.fields_by_name['btc'].message_type = chain__events__pb2._BTCEVENT
_CHAINEVENT.fields_by_name['validator'].message_type = chain__events__pb2._VALIDATOREVENT
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['builtin'])
_CHAINEVENT.fields_by_name['builtin'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['erc20'])
_CHAINEVENT.fields_by_name['erc20'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['btc'])
_CHAINEVENT.fields_by_name['btc'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['validator'])
_CHAINEVENT.fields_by_name['validator'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['NodeRegistration'] = _NODEREGISTRATION
DESCRIPTOR.message_types_by_name['NodeVote'] = _NODEVOTE
DESCRIPTOR.message_types_by_name['NodeSignature'] = _NODESIGNATURE
DESCRIPTOR.message_types_by_name['ChainEvent'] = _CHAINEVENT
DESCRIPTOR.enum_types_by_name['NodeSignatureKind'] = _NODESIGNATUREKIND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NodeRegistration = _reflection.GeneratedProtocolMessageType('NodeRegistration', (_message.Message,), {
  'DESCRIPTOR' : _NODEREGISTRATION,
  '__module__' : 'commands.v1.validator_commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.NodeRegistration)
  })
_sym_db.RegisterMessage(NodeRegistration)

NodeVote = _reflection.GeneratedProtocolMessageType('NodeVote', (_message.Message,), {
  'DESCRIPTOR' : _NODEVOTE,
  '__module__' : 'commands.v1.validator_commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.NodeVote)
  })
_sym_db.RegisterMessage(NodeVote)

NodeSignature = _reflection.GeneratedProtocolMessageType('NodeSignature', (_message.Message,), {
  'DESCRIPTOR' : _NODESIGNATURE,
  '__module__' : 'commands.v1.validator_commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.NodeSignature)
  })
_sym_db.RegisterMessage(NodeSignature)

ChainEvent = _reflection.GeneratedProtocolMessageType('ChainEvent', (_message.Message,), {
  'DESCRIPTOR' : _CHAINEVENT,
  '__module__' : 'commands.v1.validator_commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.ChainEvent)
  })
_sym_db.RegisterMessage(ChainEvent)


DESCRIPTOR._options = None
_NODEREGISTRATION.fields_by_name['pub_key']._options = None
_NODEREGISTRATION.fields_by_name['chain_pub_key']._options = None
_NODEVOTE.fields_by_name['pub_key']._options = None
_NODEVOTE.fields_by_name['reference']._options = None
# @@protoc_insertion_point(module_scope)



from . import commands_pb2_grpc as commands_grpc
from . import commands_pb2 as commands
from . import oracles_pb2_grpc as oracles_grpc
from . import oracles_pb2 as oracles
from . import transaction_pb2_grpc as transaction_grpc
from . import transaction_pb2 as transaction
from . import validator_commands_pb2_grpc as validator_commands_grpc
from . import validator_commands_pb2 as validator_commands

__all__ = [
    "commands_grpc",
    "commands",
    "oracles_grpc",
    "oracles",
    "transaction_grpc",
    "transaction",
    "validator_commands_grpc",
    "validator_commands",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: assets.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='assets.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'\n\024io.vegaprotocol.vegaZ\037code.vegaprotocol.io/vega/proto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0c\x61ssets.proto\x12\x04vega\"E\n\x05\x41sset\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12,\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x12.vega.AssetDetailsR\x07\x64\x65tails\"\x85\x02\n\x0c\x41ssetDetails\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06symbol\x18\x02 \x01(\tR\x06symbol\x12!\n\x0ctotal_supply\x18\x03 \x01(\tR\x0btotalSupply\x12\x1a\n\x08\x64\x65\x63imals\x18\x04 \x01(\x04R\x08\x64\x65\x63imals\x12 \n\x0cmin_lp_stake\x18\x05 \x01(\tR\nminLpStake\x12\x39\n\rbuiltin_asset\x18\x65 \x01(\x0b\x32\x12.vega.BuiltinAssetH\x00R\x0c\x62uiltinAsset\x12#\n\x05\x65rc20\x18\x66 \x01(\x0b\x32\x0b.vega.ERC20H\x00R\x05\x65rc20B\x08\n\x06source\"C\n\x0c\x42uiltinAsset\x12\x33\n\x16max_faucet_amount_mint\x18\x01 \x01(\tR\x13maxFaucetAmountMint\"2\n\x05\x45RC20\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddressB7\n\x14io.vegaprotocol.vegaZ\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
)




_ASSET = _descriptor.Descriptor(
  name='Asset',
  full_name='vega.Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.Asset.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='vega.Asset.details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=91,
)


_ASSETDETAILS = _descriptor.Descriptor(
  name='AssetDetails',
  full_name='vega.AssetDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='vega.AssetDetails.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='vega.AssetDetails.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='symbol', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_supply', full_name='vega.AssetDetails.total_supply', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='totalSupply', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='vega.AssetDetails.decimals', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='decimals', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_lp_stake', full_name='vega.AssetDetails.min_lp_stake', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='minLpStake', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='builtin_asset', full_name='vega.AssetDetails.builtin_asset', index=5,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='builtinAsset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='erc20', full_name='vega.AssetDetails.erc20', index=6,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='erc20', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='vega.AssetDetails.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=94,
  serialized_end=355,
)


_BUILTINASSET = _descriptor.Descriptor(
  name='BuiltinAsset',
  full_name='vega.BuiltinAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_faucet_amount_mint', full_name='vega.BuiltinAsset.max_faucet_amount_mint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxFaucetAmountMint', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=424,
)


_ERC20 = _descriptor.Descriptor(
  name='ERC20',
  full_name='vega.ERC20',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contract_address', full_name='vega.ERC20.contract_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='contractAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=476,
)

_ASSET.fields_by_name['details'].message_type = _ASSETDETAILS
_ASSETDETAILS.fields_by_name['builtin_asset'].message_type = _BUILTINASSET
_ASSETDETAILS.fields_by_name['erc20'].message_type = _ERC20
_ASSETDETAILS.oneofs_by_name['source'].fields.append(
  _ASSETDETAILS.fields_by_name['builtin_asset'])
_ASSETDETAILS.fields_by_name['builtin_asset'].containing_oneof = _ASSETDETAILS.oneofs_by_name['source']
_ASSETDETAILS.oneofs_by_name['source'].fields.append(
  _ASSETDETAILS.fields_by_name['erc20'])
_ASSETDETAILS.fields_by_name['erc20'].containing_oneof = _ASSETDETAILS.oneofs_by_name['source']
DESCRIPTOR.message_types_by_name['Asset'] = _ASSET
DESCRIPTOR.message_types_by_name['AssetDetails'] = _ASSETDETAILS
DESCRIPTOR.message_types_by_name['BuiltinAsset'] = _BUILTINASSET
DESCRIPTOR.message_types_by_name['ERC20'] = _ERC20
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), {
  'DESCRIPTOR' : _ASSET,
  '__module__' : 'assets_pb2'
  # @@protoc_insertion_point(class_scope:vega.Asset)
  })
_sym_db.RegisterMessage(Asset)

AssetDetails = _reflection.GeneratedProtocolMessageType('AssetDetails', (_message.Message,), {
  'DESCRIPTOR' : _ASSETDETAILS,
  '__module__' : 'assets_pb2'
  # @@protoc_insertion_point(class_scope:vega.AssetDetails)
  })
_sym_db.RegisterMessage(AssetDetails)

BuiltinAsset = _reflection.GeneratedProtocolMessageType('BuiltinAsset', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSET,
  '__module__' : 'assets_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAsset)
  })
_sym_db.RegisterMessage(BuiltinAsset)

ERC20 = _reflection.GeneratedProtocolMessageType('ERC20', (_message.Message,), {
  'DESCRIPTOR' : _ERC20,
  '__module__' : 'assets_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20)
  })
_sym_db.RegisterMessage(ERC20)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
